import 'dart:async';
import 'package:zhiying_comm/zhiying_comm.dart';

///
/// 底部导航栏数据Repository
///
class BottomNavRepository {

  /// 获取网络数据
  Future<dynamic> fetchNetData() async {
    try {
      var result = await NetUtil.post('/api/v1/new/config.json', method: NetMethod.GET, cache: true);
      if (NetUtil.isSuccess(result) && !EmptyUtil.isEmpty(result[GlobalConfig.HTTP_RESPONSE_KEY_DATA])) {
        return result[GlobalConfig.HTTP_RESPONSE_KEY_DATA];
      }
    } catch (e, s) {
      Logger.error(e, s);
    }
    return null;
  }

  /// 获取缓存数据
  Future<dynamic> fetchCacheData() async {
    try {
      var result = await NetUtil.getRequestCachedData('/api/v1/new/config.json');
      if (!EmptyUtil.isEmpty(result)) {
        return result;
      }
    } catch (e, s) {
      Logger.error(e, s);
    }
    return null;
  }

  ///
  /// 校验底部导航栏是否更新
  ///
  /// 校验的规则：使用 bottom_nav 的 mod_id + mod_pid + template_id + data 进行MD5
  /// ⚠️ 由于Register初始化/api/v1/new/config.json没有进行缓存，可以利用这规则，如果Register的init进行了接口缓存则需要修改逻辑
  ///
  /// false: 不更新 true 更新
  ///
  Future<bool> validateBottomNavUpdate() async {
    bool rlt = false;
    try {
      var cacheData = await fetchCacheData();
      var netData = await fetchNetData();
      if (!EmptyUtil.isEmpty(netData) && !EmptyUtil.isEmpty(cacheData)) {
        var netBottomNav = netData['bottom_nav'];
        var cacheBottomNav = cacheData['bottom_nav'];
        if (!EmptyUtil.isEmpty(netBottomNav) && !EmptyUtil.isEmpty(cacheBottomNav)) {
          var netEncodeStr = new StringBuffer();
          var cacheEncodeStr = new StringBuffer();
          netEncodeStr..write(netBottomNav['mod_id'])..write('-')..write(netBottomNav['mod_pid'])..write('-')..write(netBottomNav['template_id'])..write(netBottomNav['data']);
          cacheEncodeStr..write(cacheBottomNav['mod_id'])..write('-')..write(cacheBottomNav['mod_pid'])..write('-')..write(cacheBottomNav['template_id'])..write(cacheBottomNav['data']);
          String netMD5 = EncodeUtil.generateMd5(netEncodeStr.toString());
          String cacheMD5 = EncodeUtil.generateMd5(cacheEncodeStr.toString());
          Logger.log('网络数据的MD5 = ${netMD5}, 本地数据的MD5 = ${cacheMD5}');
          rlt = (netMD5 != cacheMD5);
        }
      }
    } catch (e, s) {
      Logger.error(e, s);
    }
    return rlt;
  }
}
